#include <vector>
#include <list>
#include <map>
#include <set>
#include <deque>
#include <stack>
#include <bitset>
#include <algorithm>
#include <functional>
#include <numeric>
#include <utility>
#include <sstream>
#include <iostream>
#include <iomanip>
#include <cstdio>
#include <cmath>
#include <cstdlib>
#include <ctime>

using namespace std;

class TheBeautifulBoard {
public:
	static int count(int, vector <int>);
};

const long long P = 1234567891LL;

long long powmod(long long a, long long n) {
	if (n == 0) {
		return 1LL;
	}

	long long b = powmod(a, n / 2LL);
	b = (b * b) % P;
	if (n % 2LL == 0LL) {
		return b;
	}
	return (a * b) % P;
}

long long inverse(long long a) {
	return powmod(a, P - 2LL);
}

const int maxN = 110000;
long long inv[maxN];

long long cnk(long long n, long long k) {
	long long res = 1;
	for (long long i = 1; i <= k; ++i) {
		res *= ((n - i + 1LL) % P);
		res %= P;
		res *= inv[i];
		res %= P;
	}
	return res;
}

long long calculate(long long n, const vector < long long > &a) {
	long long res = 1LL;
	for (int i = 0; i < a.size(); ++i) {
		if (n < a[i]) {
			return 0LL;
		}
		res *= cnk(n, a[i]);
		res %= P;
		n -= a[i];
	}
	return res;
}

long long calculateD(long long n, vector < long long > a) {
	if (n % 2 == 0) {
		for (int i = 0; i < a.size(); ++i) {
			if (a[i] % 4LL != 0LL) {
				return 0LL;
			}
			a[i] /= 4LL;
		}

		long long m = (n * n) / 4LL;
		return calculate(m, a);
	} else {
		long long res = 0;
		for (int i = 0; i < a.size(); ++i) {
			if (a[i] == 0) {
				continue;
			}
			vector < long long > b = a;
			--b[i];
			bool good = true;
			for (int j = 0; j < b.size(); ++j) {
				if (b[j] % 4LL != 0LL) {
					good = false;
				}
				b[j] /= 4LL;
			}

			long long m = (n * n) / 4LL;
			if (good) {
				res += calculate(m, b);
				res %= P;
			}
		}

		for (int i = 0; i < a.size(); ++i) {
			if (a[i] % 4LL != 0LL) {
				return res;
			}
			a[i] /= 4LL;
		}
		long long m = (n * n) / 4LL;
		res += calculate(m, a);
		res %= P;

		return res;
	}
}

long long calculateC(long long n, vector < long long > a) {
	if (n % 2 == 0) {
		for (int i = 0; i < a.size(); ++i) {
			if (a[i] % 2LL != 0LL) {
				return 0LL;
			}
			a[i] /= 2LL;
		}

		long long m = (n * n) / 2LL;
		return calculate(m, a);
	} else {
		long long res = 0;
		for (int i = 0; i < a.size(); ++i) {
			if (a[i] == 0) {
				continue;
			}
			vector < long long > b = a;
			--b[i];
			bool good = true;
			for (int j = 0; j < b.size(); ++j) {
				if (b[j] % 2LL != 0LL) {
					good = false;
				}
				b[j] /= 2LL;
			}

			long long m = (n * n) / 2LL;
			if (good) {
				res += calculate(m, b);
				res %= P;
			}
		}

		for (int i = 0; i < a.size(); ++i) {
			if (a[i] % 2LL != 0LL) {
				return res;
			}
			a[i] /= 2LL;
		}
		long long m = (n * n) / 2LL;
		res += calculate(m, a);
		res %= P;

		return res;
	}
}

int TheBeautifulBoard::count(int n, vector <int> checkers) {
	for (int i = 1; i < maxN; ++i) {
		inv[i] = inverse(i);
	}

	vector < long long > a;
	long long s = 0;
	for (int i = 0; i < checkers.size(); ++i) {
		a.push_back(checkers[i]);
		s += a.back();
	}

	if (s > (long long)(n) * (long long)(n)) {
		return 0LL;
	}

	long long A = calculate((long long)(n) * (long long)(n), a);
	long long C = calculateC(n, a);
	long long D = calculateD(n, a);

	C -= D;
	long long res = (A + D + D + D + C) * inv[4];
	res %= P;
	return (res + P) % P;
}

int main() {
	int n, m;
	cin >> n >> m;
	vector < int > a(m);
	for (int i = 0; i < m; ++i) {
		cin >> a[i];
	}
	cout << TheBeautifulBoard::count(n, a) << endl;

	return 0;
}