import java.io.*;
import java.util.*;
import java.math.*;

import javax.swing.text.html.HTMLDocument.HTMLReader.HiddenAction;

public class D implements Runnable {
	private static BufferedReader in;
	private static StringTokenizer st;
	private static PrintWriter out;

	static class State {
		int value, taken, skipBefore, skipSame, freeBefore, freeSame, freeNext;

		public State(int value, int taken, int skipBefore, int skipSame,
				int freeBefore, int freeSame, int freeNext) {
			this.value = value;
			this.taken = taken;
			this.skipBefore = skipBefore;
			this.skipSame = skipSame;
			this.freeBefore = freeBefore;
			this.freeSame = freeSame;
			this.freeNext = freeNext;
		}

		@Override
		public int hashCode() {
			final int prime = 31;
			int result = 1;
			result = prime * result + freeBefore;
			result = prime * result + freeNext;
			result = prime * result + freeSame;
			result = prime * result + skipBefore;
			result = prime * result + skipSame;
			result = prime * result + taken;
			result = prime * result + value;
			return result;
		}

		@Override
		public boolean equals(Object obj) {
			if (this == obj)
				return true;
			if (obj == null)
				return false;
			if (getClass() != obj.getClass())
				return false;
			State other = (State) obj;
			if (freeBefore != other.freeBefore)
				return false;
			if (freeNext != other.freeNext)
				return false;
			if (freeSame != other.freeSame)
				return false;
			if (skipBefore != other.skipBefore)
				return false;
			if (skipSame != other.skipSame)
				return false;
			if (taken != other.taken)
				return false;
			if (value != other.value)
				return false;
			return true;
		}

		@Override
		public String toString() {
			return "State [value=" + value + ", taken=" + taken
					+ ", skipBefore=" + skipBefore + ", skipSame=" + skipSame
					+ ", freeBefore=" + freeBefore + ", freeSame=" + freeSame
					+ ", freeNext=" + freeNext + "]";
		}

	}

	final int numberStates = 3;
	final int none = -1, free = 0, taken = 1, must = 2;

	private void solve() throws IOException {
		int numbersCount = nextInt();
		int[] numbers = new int[numbersCount];
		for (int i = 0; i < numbersCount; i++) {
			numbers[i] = nextInt();
		}

		//out.println(solveDumb(numbersCount, numbers));
		out.println(solveSmart(numbersCount, numbers));
	}

	private int solveDumb(int numbersCount, int[] numbers) {
		int maxValue = 0;
		for (int value : numbers)
			maxValue = Math.max(maxValue, value);
		int[] howMuch = new int[maxValue + 2];
		for (int i = 0; i < numbersCount; i++) {
			++howMuch[numbers[i]];
		}
		int result = rec(0, numbersCount, numbers, howMuch, maxValue);
		return result;
	}

	private int rec(int step, int numbersCount, int[] numbers, int[] howMuch,
			int maxValue) {
		if (step == numbersCount) {
			return 0;
		} else {
			List<Integer> free = new ArrayList<>();
			for (int d = -1; d <= 1; d++) {
				int value = numbers[step] + d;
				if (value >= 0 && value <= maxValue && howMuch[value] > 0) {
					free.add(value);
				}
			}
			if (free.isEmpty()) {
				return 1 + rec(step + 1, numbersCount, numbers, howMuch,
						maxValue);
			} else {
				int result = 0;
				for (int value : free) {
					--howMuch[value];
					result = Math.max(
							result,
							rec(step + 1, numbersCount, numbers, howMuch,
									maxValue));
					++howMuch[value];
				}
				return result;
			}
		}
	}

	private int solveSmart(int numbersCount, int[] numbers) {
		numbers = Arrays.copyOf(numbers, numbersCount);
		Arrays.sort(numbers);
		int maxValue = 0;
		for (int value : numbers)
			maxValue = Math.max(maxValue, value);
		int[] howMuch = new int[maxValue + 3];
		for (int value : numbers)
			++howMuch[value];
		int result = rec(0, 0, 0, 0, 0, 0, howMuch[1], maxValue, howMuch);
		return result;
	}

	Map<State, Integer> cache = new HashMap<>();

	private int rec(int value, int taken, int skipBefore, int skipSame,
			int freeBefore, int freeSame, int freeNext, int maxValue,
			int[] howMuch) {

		final int inf = 128;

		if (value > maxValue) {
			if (skipBefore != 0 && (freeBefore + freeSame != 0)) {
				return -inf;
			} else if (skipSame != 0 && freeBefore != 0) {
				return -inf;
			} else {
				return 0;
			}
		}
		State state = new State(value, taken, skipBefore, skipSame,
				freeBefore, freeSame, freeNext);
		Integer resultInCache = cache.get(state);
		if (resultInCache != null)
			return resultInCache;

		int newResult = -inf;

		if (taken == howMuch[value]) {
			if (skipBefore != 0 && (freeBefore + freeSame != 0)) {
				// bad
			} else if (skipSame != 0 && freeBefore != 0) {
				// bad
			} else {
				newResult = rec(value + 1, 0, skipSame, 0, freeSame, freeNext,
						howMuch[value + 2], maxValue, howMuch);
			}
		} else {
			if (freeBefore > 0)
				newResult = rec(value, taken + 1, skipBefore, skipSame,
						freeBefore - 1, freeSame, freeNext, maxValue, howMuch);
			if (freeSame > 0) {
				newResult = Math.max(
						newResult,
						rec(value, taken + 1, skipBefore, skipSame, freeBefore,
								freeSame - 1, freeNext, maxValue, howMuch));
			}
			if (freeNext > 0) {
				newResult = Math.max(
						newResult,
						rec(value, taken + 1, skipBefore, skipSame, freeBefore,
								freeSame, freeNext - 1, maxValue, howMuch));
			}
			newResult = Math.max(
					newResult,
					rec(value, taken + 1, skipBefore, skipSame + 1, freeBefore,
							freeSame, freeNext, maxValue, howMuch) + 1);
		}

		//out.println(state + " " + newResult);

		cache.put(state, newResult);

		return newResult;
	}

	public void run() {
		try {
			in = new BufferedReader(new InputStreamReader(System.in));
			out = new PrintWriter(System.out);

			solve();

			out.close();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}

	public static void main(String[] args) {
		new D().run();
	}

	private String nextToken() throws IOException {
		while (st == null || !st.hasMoreTokens()) {
			String line = in.readLine();
			if (line == null) {
				return null;
			}
			st = new StringTokenizer(line);
		}
		return st.nextToken();
	}

	private int nextInt() throws IOException {
		return Integer.parseInt(nextToken());
	}

	private long nextLong() throws IOException {
		return Long.parseLong(nextToken());
	}

	private double nextDouble() throws IOException {
		return Double.parseDouble(nextToken());
	}

}
